@@ -4,13 +4,13 @@
 # Copyright: Toshio Kuratomi
 # License: GPL
 # Description: Main QAReviewer application object
-# Id: $Id: qareviewer.py 200 2005-09-12 22:50:10Z abadger1999 $
+# Id: $Id: qareviewer.py 216 2006-05-23 15:50:08Z abadger1999 $
 """QA Reviewer object.
 
 The main program object.  From here we set up the user interface, receive
 events, and send things off for future processing.
 """
-__revision__ = "$Rev: 200 $"
+__revision__ = "$Rev: 216 $"
 
 import sys
 import os
@@ -80,7 +80,7 @@ class QAReviewer(gnomeglade.GnomeApp):
         self.reviewPane.add(self.reviewView)
 
         self.grabArrow = gtk.Arrow(gtk.ARROW_LEFT, gtk.SHADOW_NONE)
-        self.grabArrow.set_size_request(4,4)
+        self.grabArrow.set_size_request(8,8)
         label = self.grabBar.get_child()
         self.grabBar.remove(label)
         self.grabBar.add(self.grabArrow)
@@ -308,7 +308,7 @@ Relative Priority: Low.  The program is currently changing too fast to document
 
         propDialog.show()
 
-    def toggle_preview_cb(self, action, extra):
+    def toggle_preview_cb(self, action, *extra):
         '''Toggles between checklist view and output view.
 
         Keyword -- arguments:
