@@ -5,10 +5,10 @@
 # Date: 24 September, 2004
 # Copyright: Toshio Kuratomi
 # License: GPL
-# Id: $Id: test.py 163 2005-02-21 13:30:39Z badger $
+# Id: $Id: test.py 212 2005-11-26 07:51:06Z abadger1999 $
 '''Automated testing harness to drive the unittests for QA Assistant.
 '''
-__revision__ = '$Rev: 163 $'
+__revision__ = '$Rev: 212 $'
 
 import sys
 import os
@@ -20,20 +20,25 @@ else:
     srcdir = '.'
 
 sys.path.extend((os.path.join(srcdir, '..', 'src'),
-    os.path.join('..', 'src')))
+    os.path.join('..', 'src'),
+    os.path.join(srcdir, '..', 'data'),
+    os.path.join('..', 'data')
+    ))
 
 import creationtest
 import checklisttest
 import treetipstest
 import propertiestest
+import qaconverttest
 
 if __name__ == '__main__':
     createSuite = creationtest.suite()
     propertiesSuite = propertiestest.suite()
     checkSuite = checklisttest.suite()
     treetipSuite = treetipstest.suite()
+    qaconvertSuite = qaconverttest.suite()
     suite = unittest.TestSuite((createSuite, treetipSuite, propertiesSuite,
-        checkSuite))
+        checkSuite, qaconvertSuite))
     result = unittest.TextTestRunner(verbosity=2).run(suite)
     if result.wasSuccessful():
         sys.exit(0)
